Struct
PhocInputMethodRelay
Description [src]
struct PhocInputMethodRelay {
PhocSeat* seat;
wl_list text_inputs;
wlr_input_method_v2* input_method;
wl_listener text_input_new;
wl_listener input_method_new;
wl_listener input_method_commit;
wl_listener input_method_grab_keyboard;
wl_listener input_method_destroy;
wl_listener input_method_keyboard_grab_destroy;
}
The relay structure manages the relationship between text-input and input_method interfaces on a given seat.
Multiple text-input interfaces may be bound to a relay, but at most one will be focused (reveiving events) at a time. At most one input-method interface may be bound to the seat. The relay manages life cycle of both sides. When both sides are present and focused, the relay passes messages between them.
Text input focus is a subset of keyboard focus - if the text-input is in the focused state, wl_keyboard sent an enter as well. However, having wl_keyboard focused doesn’t mean that text-input will be focused.
Structure members
seatNo description available.
text_inputsNo description available.
input_methodNo description available.
text_input_newNo description available.
input_method_newNo description available.
input_method_commitNo description available.
input_method_grab_keyboardNo description available.
input_method_destroyNo description available.
input_method_keyboard_grab_destroyNo description available.
Instance methods
phoc_input_method_relay_set_focus
Updates the currently focused surface. Surface must belong to the same seat.